<?php
/*+*******************************************************************************
 *  The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 *
 *********************************************************************************/

/**
 * @author MAK
 */

$mod_strings = array(
	'VtigerBackup'=>'Copia Seguridad',
	'SINGLE_VtigerBackup'=>'Copia Seguridad',
	'LBL_CREATE_ZIP_FAILURE' => 'No se ha podido crear el fichero comprimido',
	'LBL_ZIP_FILE_ADD_FAILURE' => 'error añadiendo fichero',
	'LBL_FTP_CONNECT_FAILED' => 'Conexión FTP fallida',
	'LBL_FTP_LOGIN_FAILED' => 'Acceso FTP fallido',
);

?>